@@ -11,8 +11,9 @@ $DefaultPriority = Event::PRIO_HIGH();
 sub new {
     # lock %Event::
 
-    my $o = allocate(shift);
+    my $class = shift;
     my %arg = @_;
+    my $o = allocate($class, delete $arg{attach_to} || {});
     $o->init(\%arg);
     $o->start;
     $o;
